==> allensdk-2.13.0-py3-none-any.whl: allensdk/brain_observatory/behavior/data_objects/motion_correction.py <==
import pandas as pd
from pynwb import NWBFile, TimeSeries

from allensdk.brain_observatory.behavior.data_files\
    .rigid_motion_transform_file import \
    RigidMotionTransformFile
from allensdk.brain_observatory.behavior.data_objects import DataObject
from allensdk.brain_observatory.behavior.data_objects.base \
    .readable_interfaces import \
    DataFileReadableInterface, NwbReadableInterface
from allensdk.brain_observatory.behavior.data_objects.base\
    .writable_interfaces import \
    NwbWritableInterface


class MotionCorrection(DataObject, DataFileReadableInterface,
                       NwbReadableInterface, NwbWritableInterface):
    """motion correction output"""
    def __init__(self, motion_correction: pd.DataFrame):
        """
        :param motion_correction
            Columns:
                x: float
                y: float
        """
        super().__init__(name='motion_correction', value=motion_correction)

    @classmethod
    def from_data_file(
            cls, rigid_motion_transform_file: RigidMotionTransformFile) \
            -> "MotionCorrection":
        df = rigid_motion_transform_file.data
        return cls(motion_correction=df)

    @classmethod
    def from_nwb(cls, nwbfile: NWBFile) -> "MotionCorrection":
        ophys_module = nwbfile.processing['ophys']

        motion_correction_data = {
            'x': ophys_module.get_data_interface(
                'ophys_motion_correction_x').data[:],
            'y': ophys_module.get_data_interface(
                'ophys_motion_correction_y').data[:]
        }

        df = pd.DataFrame(motion_correction_data)
        return cls(motion_correction=df)

    def to_nwb(self, nwbfile: NWBFile) -> NWBFile:
        ophys_module = nwbfile.processing['ophys']
        ophys_timestamps = ophys_module.get_data_interface(
            'dff').roi_response_series['traces'].timestamps

        t1 = TimeSeries(
            name='ophys_motion_correction_x',
            data=self.value['x'].values,
            timestamps=ophys_timestamps,
            unit='pixels'
        )

        t2 = TimeSeries(
            name='ophys_motion_correction_y',
            data=self.value['y'].values,
            timestamps=ophys_timestamps,
            unit='pixels'
        )

        ophys_module.add_data_interface(t1)
        ophys_module.add_data_interface(t2)

        return nwbfile

==> allensdk-2.16.1-py3-none-any.whl: allensdk/brain_observatory/behavior/data_objects/motion_correction.py <==
import pandas as pd
from pynwb import NWBFile, TimeSeries

from allensdk.brain_observatory.behavior.data_files\
    .rigid_motion_transform_file import \
    RigidMotionTransformFile
from allensdk.core import DataObject
from allensdk.core import \
    DataFileReadableInterface, NwbReadableInterface
from allensdk.core import \
    NwbWritableInterface


class MotionCorrection(DataObject, DataFileReadableInterface,
                       NwbReadableInterface, NwbWritableInterface):
    """motion correction output"""
    def __init__(self, motion_correction: pd.DataFrame):
        """
        :param motion_correction
            Columns:
                x: float
                y: float
        """
        super().__init__(name='motion_correction', value=motion_correction)

    @classmethod
    def from_data_file(
            cls, rigid_motion_transform_file: RigidMotionTransformFile) \
            -> "MotionCorrection":
        df = rigid_motion_transform_file.data
        return cls(motion_correction=df)

    @classmethod
    def from_nwb(cls, nwbfile: NWBFile) -> "MotionCorrection":
        ophys_module = nwbfile.processing['ophys']

        motion_correction_data = {
            'x': ophys_module.get_data_interface(
                'ophys_motion_correction_x').data[:],
            'y': ophys_module.get_data_interface(
                'ophys_motion_correction_y').data[:]
        }

        df = pd.DataFrame(motion_correction_data)
        return cls(motion_correction=df)

    def to_nwb(self, nwbfile: NWBFile) -> NWBFile:
        ophys_module = nwbfile.processing['ophys']
        ophys_timestamps = ophys_module.get_data_interface(
            'dff').roi_response_series['traces'].timestamps

        t1 = TimeSeries(
            name='ophys_motion_correction_x',
            data=self.value['x'].values,
            timestamps=ophys_timestamps,
            unit='pixels'
        )

        t2 = TimeSeries(
            name='ophys_motion_correction_y',
            data=self.value['y'].values,
            timestamps=ophys_timestamps,
            unit='pixels'
        )

        ophys_module.add_data_interface(t1)
        ophys_module.add_data_interface(t2)

        return nwbfile
